function [Out,bDs,Error]=set_solve(N,verbose,varargin)
  % example of 'set_fun' function used in bench
  p = inputParser;
  p.KeepUnmatched=true; 
  p.PartialMatching=false;
  p.addParamValue('d',2,@isscalar);% matrices d-by-d
  p.addParamValue('n',1,@isscalar); % RHS d-by-n
  p.addParamValue('fprintf',@(varargin) fprintf(varargin{:}));
  p.addParamValue('kind','gen',@(x) ismember(lower(x),{'triu','tril','diag','gen'})); 
  p.addParamValue('class','double',@(x) ismember(x,{'double','single'}));
  p.addParamValue('rhstype','amat',@(s) ismember(lower(s),{'amat','mat'}));
  p.addParamValue('a',0.5,@isscalar); 
  p.addParamValue('b',2,@isscalar); 
  p.addParamValue('complex',false,@islogical);
  p.parse(varargin{:});
  R=p.Results;
  classname=R.class;
  Fprintf=R.fprintf;
  d=R.d;
  varargin=fc_tools.utils.deleteCellOptions(varargin,p.Parameters);
  
  switch lower(R.kind)
    case 'gen'
      A=fc_amat.random.randnsdd(N,d,'class',classname,'complex',R.complex);
      str0='strictly diagonally dominant matrices';
    case 'triu'
      A=fc_amat.random.randtriu(N,d,'class',classname,'complex',R.complex,'a',R.a,'b',R.b);
      str0='upper triangular matrices';
    case 'tril'
      A=fc_amat.random.randtril(N,d,'class',classname,'complex',R.complex,'a',R.a,'b',R.b);
      str0='lower triangular matrices';
    case 'diag'
      A=fc_amat.random.randdiag(N,d,'class',classname,'complex',R.complex,'a',R.a,'b',R.b);
      str0='diagonal matrices';
  end
  if ~isreal(A), str=['complex ',subclass(A)]; else, str=subclass(A);end
  
  if verbose 
    Fprintf('# 1st parameter is :\n');
    Fprintf('# -> amat[%s] with (N,m,n)=(N,%d,%d)\n',str,size(A,1),size(A,2));
    Fprintf('#    containing %s\n',str0);
    
  end
  
  if verbose, Fprintf('# 2nd parameter is :\n');end
  [B,~,~]=fc_amat.benchs.set_datas(N,verbose,'d',[d,R.n],'type',R.rhstype,'class',classname,'complex',R.complex,'fprintf',Fprintf,varargin{:});
  B=B{1};
  if ~isreal(A)
    str=['complex ',classname]; 
  else
    str=classname; 
  end
  
  Error={@(X) max(norm(A*X-B))};
  
  if verbose
    Fprintf('# Error function: %s\n',fc_tools.utils.fun2str(Error{1}));
  end
  bDs{1}=fc_bench.bdata('N',N,'%d',10);
  Out={A,B};
end
